package com.ruoyi.bid.service;

import java.util.List;
import com.ruoyi.bid.domain.BidSite;

/**
 * 常用网站Service接口
 * 
 * @author ruoyi
 * @date 2025-12-09
 */
public interface IBidSiteService 
{
    /**
     * 查询常用网站
     * 
     * @param id 常用网站主键
     * @return 常用网站
     */
    public BidSite selectBidSiteById(Long id);

    /**
     * 查询常用网站列表
     * 
     * @param bidSite 常用网站
     * @return 常用网站集合
     */
    public List<BidSite> selectBidSiteList(BidSite bidSite);

    /**
     * 新增常用网站
     * 
     * @param bidSite 常用网站
     * @return 结果
     */
    public int insertBidSite(BidSite bidSite);

    /**
     * 修改常用网站
     * 
     * @param bidSite 常用网站
     * @return 结果
     */
    public int updateBidSite(BidSite bidSite);

    /**
     * 批量删除常用网站
     * 
     * @param ids 需要删除的常用网站主键集合
     * @return 结果
     */
    public int deleteBidSiteByIds(Long[] ids);

    /**
     * 删除常用网站信息
     * 
     * @param id 常用网站主键
     * @return 结果
     */
    public int deleteBidSiteById(Long id);
}
